@@ -13,9 +13,7 @@ from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin
 from collective.classifieds.config import *
 
 
-
 schema = Schema((
-
     TextField(
         name='description',
         allowable_content_types=('text/plain', 'text/html',),
@@ -83,22 +81,30 @@ schema = Schema((
         required=False,
         searchable=True,
     ),
-    
+    StringField(
+        name='externalurl',
+        widget=StringWidget(
+            label="External URL",
+            description="External URL to find more information about the classified",
+            label_msgid="classifieds_classified_externalurl",
+            description_msgid="classifieds_classified_externalurl_description",
+            i18n_domain='classifieds',
+        ),
+        validators=('isURL',),
+        required=False,
+        searchable=False,
+    ),
 ),
 )
 
-
 Classified_schema = BaseSchema.copy() + \
     schema.copy()
 
-
 class Classified(BaseContent, BrowserDefaultMixin):
     """
         Represents a Classified
     """
-
     security = ClassSecurityInfo()
-
     implements(interfaces.IClassified)
 
     meta_type = 'Classified'
@@ -124,7 +130,7 @@ class Classified(BaseContent, BrowserDefaultMixin):
             portal_url = getToolByName(self, 'portal_url').getPortalObject().absolute_url(1)
             imgtileurl = imgtileurl.replace(portal_url, '')
             return imgtileurl
-        return ''    
+        return ''
 
     def getClassifiedsCategory(self):
         """Get classifieds category"""
@@ -136,7 +142,6 @@ class Classified(BaseContent, BrowserDefaultMixin):
 
     def check_delete_permission(self):
         """Check if user may delete object"""
-
         if getSecurityManager().checkPermission("Delete objects", self):
             if getSecurityManager().getUser().getUserName() == self.getOwner().getId():
                 return True
@@ -145,12 +150,9 @@ class Classified(BaseContent, BrowserDefaultMixin):
     def delete(self):
         """Delete this object"""
         parent = self.aq_inner.aq_parent
-
         if self.check_delete_permission():
             parent._delObject(self.id)
-
             return self.REQUEST.RESPONSE.redirect( "%s?classified_title=%s&portal_status_message=%s" % (parent.absolute_url(), self.Title(), "has been deleted."))
-
         return self.REQUEST.RESPONSE.redirect( "%s?classified_title=%s&portal_status_message=%s %s" % (parent.absolute_url(), self.Title(), "has NOT been deleted."))
 
 registerType(Classified, PROJECTNAME)
